<table style="width: 95%; margin: 15px auto; border: 1px solid #303d50; border-collapse: collapse; font-family: 'Roboto', sans-serif; page-break-inside: avoid;">
    <tbody>
    {% for fila in filas %}
    <tr>
        <!-- Par 1 -->
        <td style="width: 20%; border: 1px solid #303d50; padding: 8px; font-weight: bold; background-color: #f8f8f8; font-size: 10pt; word-break: break-word;">
            {% if fila.0.clave %}{{ fila.0.clave|upper }}{% endif %}
        </td>
        <td style="width: 30%; border: 1px solid #303d50; padding: 8px; font-size: 10pt; word-break: break-word;">
            {% if fila.0.valor %}{{ fila.0.valor }}{% else %}-{% endif %}
        </td>

        <!-- Par 2 -->
        <td style="width: 20%; border: 1px solid #303d50; padding: 8px; font-weight: bold; background-color: #f8f8f8; font-size: 10pt; word-break: break-word;">
            {% if fila.1.clave %}{{ fila.1.clave|upper }}{% endif %}
        </td>
        <td style="width: 30%; border: 1px solid #303d50; padding: 8px; font-size: 10pt; word-break: break-word;">
            {% if fila.1.valor %}{{ fila.1.valor }}{% else %}-{% endif %}
        </td>
    </tr>
    {% empty %}
    <tr>
      <td colspan="4" style="text-align: center; padding: 10px; font-style: italic;">
        No hay datos disponibles
      </td>
    </tr>
    {% endfor %}
  </tbody>
</table>